@@ -1,6 +1,7 @@
 from odin_messages.base import BaseEventMessage
 
-class NewOrderMessage(BaseEventMessage):
+
+class NewLimitOrderMessage(BaseEventMessage):
     exchange: str
     market_code: str
     limit_price: str
@@ -9,6 +10,15 @@ class NewOrderMessage(BaseEventMessage):
     price_delta: float
     selling: bool
 
+
+class NewSpotOrderMessage(BaseEventMessage):
+    exchange: str
+    market_code: str
+    quantity: float
+    usd_price: float
+    selling: bool
+
+
 class CancelOrderMessage(BaseEventMessage):
     order_id: str
     exchange: str
@@ -21,9 +31,3 @@ class UpdateOrderMessage(BaseEventMessage):
     exchange: str
     new_limit_price: float
     new_quantity: float
-
-    
-
-
-
-
