@@ -7,4 +7,6 @@ class PriceWatchMessage(BaseEventMessage):
     exchange: str
     market_code: str
     ask_price: float
+    ask_delta: float
     bid_price: float
+    bid_delta: float
